==> ihunt-0.1.1-py3-none-any.whl: ihunt/apis/urldna.py <==
# Docs: https://urldna.io/api

import json
import requests
from threading import Lock
import time
from ..models import Ihunt
from ..stdout import echo

BASE_URL = "https://api.urldna.io/scan"


# Query: URL
# Return: Info
def req_urldna_url(ihunt: Ihunt, lock: Lock) -> None:
    echo("[*] Fetching urlDNA...", ihunt.verbose)

    url = BASE_URL
    headers = {
        "Authorization": ihunt.apikeys.urldna,
        "Content-Type": "application/json",
    }
    data = {
        "submitted_url": ihunt.query.value,
    }

    try:
        resp = requests.post(url, headers=headers, data=json.dumps(data))
        if resp.status_code != 200:
            return
        with lock:
            d = resp.json()
            scan_id = d["id"]
            url = BASE_URL + f"/{scan_id}"

            # Get scan result (wait for the scan status is "DONE")
            while True:
                echo("[*] Waiting for the scan result...", ihunt.verbose)
                time.sleep(5)

                resp = requests.get(url, headers=headers)
                if resp.status_code != 200:
                    return
            
                d = resp.json()
                scan_status = d["scan"]["status"]

                if scan_status == "RUNNING" or scan_status == "PENDING":
                    continue
                elif scan_status == "ERROR":
                    echo(f"[x] urlDNA API error: The scan failed.", ihunt.verbose)
                    return
                elif scan_status == "DONE":
                    if ihunt.data.cert_issuer is None:
                        ihunt.data.cert_issuer = d["certificate"]["issuer"]
                    if ihunt.data.cert_subject is None:
                        ihunt.data.cert_subject = d["certificate"]["subject"]
                    if ihunt.data.cert_serial_number is None:
                        ihunt.data.cert_serial_number = d["certificate"]["serial_number"]
                    if ihunt.data.console_messages is None:
                        ihunt.data.console_messages = []
                        for msg in d["console_messages"]:
                            ihunt.data.console_messages.append(msg)
                    if ihunt.data.cookies is None:
                        ihunt.data.cookies = d["cookies"]
                    if ihunt.data.dom is None:
                        ihunt.data.dom = d["dom"]
                    if ihunt.data.favicon is None:
                        ihunt.data.favicon = d["favicon"]
                    if ihunt.data.ip is None:
                        ihunt.data.ip = d["ip_address"]["ip"]
                    if ihunt.data.asn is None:
                        ihunt.data.asn = d["ip_address"]["asn"]
                    if ihunt.data.isp is None:
                        ihunt.data.isp = d["ip_address"]["isp"]
                    if ihunt.data.organization is None:
                        ihunt.data.organization = d["ip_address"]["org"]
                    if ihunt.data.country_name is None:
                        ihunt.data.country_name = d["ip_address"]["country"]
                    if ihunt.data.country_code is None:
                        ihunt.data.country_code = d["ip_address"]["country_code"]
                    if ihunt.data.region is None:
                        ihunt.data.region = d["ip_address"]["region"]
                    if ihunt.data.city is None:
                        ihunt.data.city = d["ip_address"]["city"]
                    if ihunt.data.latitude is None:
                        ihunt.data.latitude = str(d["ip_address"]["latitude"])
                    if ihunt.data.longitude is None:
                        ihunt.data.longitude = str(d["ip_address"]["longitude"])
                    if ihunt.data.malicious is None:
                        ihunt.data.malicious = d["malicious"]
                    if ihunt.data.page is None:
                        ihunt.data.page = d["page"]
                    if ihunt.data.screenshot is None:
                        ihunt.data.screenshot = d["screenshot"]
                    if ihunt.data.technologies is None:
                        ihunt.data.technologies = d["technologies"]
                    break
    except Exception as e:
        echo(f"[x] urlDNA API error: {e}", ihunt.verbose)

    echo("[*] Finished fetching urlDNA.", ihunt.verbose)

==> ihunt-0.1.3-py3-none-any.whl: ihunt/apis/urldna.py <==
# Docs: https://urldna.io/api

import json
import requests
from threading import Lock
import time
from ..models import Ihunt
from ..stdout import echo
from ..utils import is_empty

BASE_URL = "https://api.urldna.io/scan"


# Query: URL
# Return: Info
def req_urldna_url(ihunt: Ihunt, lock: Lock) -> None:
    echo("[*] Fetching urlDNA...", ihunt.verbose)

    url = BASE_URL
    headers = {
        "Authorization": ihunt.apikeys.urldna,
        "Content-Type": "application/json",
    }
    data = {
        "submitted_url": ihunt.query.value,
    }

    try:
        resp = requests.post(url, headers=headers, data=json.dumps(data), timeout=ihunt.timeout)
        if resp.status_code != 200:
            return
        with lock:
            d = resp.json()
            scan_id = d["id"]
            url = BASE_URL + f"/{scan_id}"

            # Get scan result (wait for the scan status is "DONE")
            while True:
                echo("[*] Waiting for the scan result...", ihunt.verbose)
                time.sleep(5)

                resp = requests.get(url, headers=headers)
                if resp.status_code != 200:
                    return
            
                d = resp.json()
                scan_status = d["scan"]["status"]

                if scan_status == "RUNNING" or scan_status == "PENDING":
                    continue
                elif scan_status == "ERROR":
                    echo(f"[x] urlDNA API error: The scan failed.", ihunt.verbose)
                    return
                elif scan_status == "DONE":
                    if is_empty(ihunt.data.cert_issuer):
                        ihunt.data.cert_issuer = d["certificate"]["issuer"]
                    if is_empty(ihunt.data.cert_subject):
                        ihunt.data.cert_subject = d["certificate"]["subject"]
                    if is_empty(ihunt.data.cert_serial_number):
                        ihunt.data.cert_serial_number = d["certificate"]["serial_number"]
                    if is_empty(ihunt.data.console_messages):
                        ihunt.data.console_messages = []
                        for msg in d["console_messages"]:
                            ihunt.data.console_messages.append(msg)
                    if is_empty(ihunt.data.cookies):
                        ihunt.data.cookies = d["cookies"]
                    if is_empty(ihunt.data.dom):
                        ihunt.data.dom = d["dom"]
                    if is_empty(ihunt.data.favicon):
                        ihunt.data.favicon = d["favicon"]
                    if is_empty(ihunt.data.ip):
                        ihunt.data.ip = d["ip_address"]["ip"]
                    if is_empty(ihunt.data.asn):
                        ihunt.data.asn = d["ip_address"]["asn"]
                    if is_empty(ihunt.data.isp):
                        ihunt.data.isp = d["ip_address"]["isp"]
                    if is_empty(ihunt.data.organization):
                        ihunt.data.organization = d["ip_address"]["org"]
                    if is_empty(ihunt.data.country_name):
                        ihunt.data.country_name = d["ip_address"]["country"]
                    if is_empty(ihunt.data.country_code):
                        ihunt.data.country_code = d["ip_address"]["country_code"]
                    if is_empty(ihunt.data.region):
                        ihunt.data.region = d["ip_address"]["region"]
                    if is_empty(ihunt.data.city):
                        ihunt.data.city = d["ip_address"]["city"]
                    if is_empty(ihunt.data.latitude):
                        ihunt.data.latitude = str(d["ip_address"]["latitude"])
                    if is_empty(ihunt.data.longitude):
                        ihunt.data.longitude = str(d["ip_address"]["longitude"])
                    if is_empty(ihunt.data.malicious):
                        ihunt.data.malicious = d["malicious"]
                    if is_empty(ihunt.data.page):
                        ihunt.data.page = d["page"]
                    if is_empty(ihunt.data.screenshot):
                        ihunt.data.screenshot = d["screenshot"]
                    if is_empty(ihunt.data.technologies):
                        ihunt.data.technologies = d["technologies"]
                    break
    except Exception as e:
        echo(f"[x] urlDNA API error: {e}", ihunt.verbose)

    echo("[*] Finished fetching urlDNA.", ihunt.verbose)
